﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using BC.NetPdfBarcodeGeneratorTrial.All;

namespace BC.NetPdfBarcodeGeneratorDemo
{
    class PDFBarcodeGeneratorDemo
    {
        public static void CreateCode128OnPDF()
        {

            PdfDoc File = new PdfDoc();

            PdfDocPage FilePage = File.AddDocPage();

            BCImage Graphics = BCImage.GetFromDocPage(FilePage);

            BCPdfBarcode barcode = new BCPdfBarcode();

            barcode.SetType = BCBarcodeSymbology.Code128;

            barcode.SetData = "www.barcodebc.com";

            barcode.SetColor = BCColor.Black;
            barcode.SetBackgroundColor = BCColor.White;

            barcode.SetBarcodeLocation = new BCPosition(150, 250);

            barcode.SetBarcodeSize = new BCSize(200, 100);

            barcode.SetTextVisible = true;

            barcode.GenerateBarcode(Graphics);

            File.Save("Code128.pdf");
            Process.Start("Code128.pdf");

        }

        public static void CreateCode39ToPDF()
        {

            PdfDoc File = new PdfDoc();

            PdfDocPage FilePage = File.AddDocPage();

            BCImage Graphics = BCImage.GetFromDocPage(FilePage);

            BCPdfBarcode barcode = new BCPdfBarcode();

            barcode.SetType = BCBarcodeSymbology.Code39;

            barcode.SetData = "WWW.BARCODEBC.COM";

            barcode.SetColor = BCColor.Black;
            barcode.SetBackgroundColor = BCColor.White;

            barcode.SetTextVisible = true;

            barcode.SetBarcodeLocation = new BCPosition(100, 100);

            barcode.SetBarcodeSize = new BCSize(200, 50);

            barcode.GenerateBarcode(Graphics);

            File.Save("Code39.pdf");
            Process.Start("Code39.pdf");

        }

        public static void CreateEan13ToPDF()
        {
            PdfDoc File = new PdfDoc();

            PdfDocPage FilePage = File.AddDocPage();

            BCImage Graphics = BCImage.GetFromDocPage(FilePage);

            BCPdfBarcode barcode = new BCPdfBarcode();

            barcode.SetType = BCBarcodeSymbology.Ean13;

            barcode.SetData = "168861168861";

            barcode.SetColor = BCColor.Black;
            barcode.SetBackgroundColor = BCColor.White;

            barcode.SetTextVisible = true;

            barcode.SetBarcodeLocation = new BCPosition(100, 100);

            barcode.SetBarcodeSize = new BCSize(200, 50);

            barcode.GenerateBarcode(Graphics);

            File.Save("Ean13.pdf");
            Process.Start("Ean13.pdf");

        }

        public static void CreateUpcaToPDF()
        {

            PdfDoc File = new PdfDoc();

            PdfDocPage FilePage = File.AddDocPage();

            BCImage Graphics = BCImage.GetFromDocPage(FilePage);

            BCPdfBarcode barcode = new BCPdfBarcode();

            barcode.SetType = BCBarcodeSymbology.Upca;

            barcode.SetData = "0123456789";

            barcode.SetColor = BCColor.Black;
            barcode.SetBackgroundColor = BCColor.White;

            barcode.SetTextVisible = true;

            barcode.SetBarcodeLocation = new BCPosition(100, 100);

            barcode.SetBarcodeSize = new BCSize(200, 50);

            barcode.GenerateBarcode(Graphics);

            File.Save("Upca.pdf");
            Process.Start("Upca.pdf");

        }

        public static void CreateQrcodeToPDF()
        {

            PdfDoc File = new PdfDoc();

            PdfDocPage FilePage = File.AddDocPage();

            BCImage Graphics = BCImage.GetFromDocPage(FilePage);

            BCPdfBarcode barcode = new BCPdfBarcode();

            barcode.SetType = BCBarcodeSymbology.Qrcode;

            barcode.SetData = "www.barcodebc.com";

            barcode.SetColor = BCColor.Black;
            barcode.SetBackgroundColor = BCColor.White;

            barcode.QrcodeECL = QrcodeECLMode.LevelL;

            barcode.SetBarcodeLocation = new BCPosition(100, 100);

            barcode.SetBarcodeSize = new BCSize(200, 200);

            barcode.GenerateBarcode(Graphics);

            File.Save("Qrcode.pdf");
            Process.Start("Qrcode.pdf");

        }
        public static void CreatePdf417ToPDF()
        {
            PdfDoc File = new PdfDoc();

            PdfDocPage FilePage = File.AddDocPage();

            BCImage Graphics = BCImage.GetFromDocPage(FilePage);

            BCPdfBarcode barcode = new BCPdfBarcode();

            barcode.SetType = BCBarcodeSymbology.Pdf417;

            barcode.SetData = "BARCODEBC123456789";

            barcode.SetColor = BCColor.Black;
            barcode.SetBackgroundColor = BCColor.White;

            barcode.Pdf417Truncated = false;

            barcode.SetBarcodeLocation = new BCPosition(70, 50);

            barcode.SetBarcodeSize = new BCSize(200, 100);

            barcode.GenerateBarcode(Graphics);

            File.Save("Pdf417.pdf");
            Process.Start("Pdf417.pdf");

        }

        public static void CreateDatamatrixToPDF()
        {

            PdfDoc File = new PdfDoc();

            PdfDocPage FilePage = File.AddDocPage();

            BCImage Graphics = BCImage.GetFromDocPage(FilePage);

            BCPdfBarcode barcode = new BCPdfBarcode();

            barcode.SetType = BCBarcodeSymbology.Datamatrix;

            barcode.SetData = "WWW.BARCODEBC.COM";

            barcode.SetColor = BCColor.Black;
            barcode.SetBackgroundColor = BCColor.White;

            barcode.DatamatrixSymbolShape = DatamatrixFormat.Automatic;

            barcode.SetBarcodeLocation = new BCPosition(100, 100);

            barcode.SetBarcodeSize = new BCSize(200, 200);

            barcode.GenerateBarcode(Graphics);

            File.Save("Datamatrix.pdf");
            Process.Start("Datamatrix.pdf");

        }

        public static void CreateAztecToPDF()
        {

            PdfDoc File = new PdfDoc();

            PdfDocPage FilePage = File.AddDocPage();

            BCImage Graphics = BCImage.GetFromDocPage(FilePage);

            BCPdfBarcode barcode = new BCPdfBarcode();

            barcode.SetType = BCBarcodeSymbology.Aztec;

            barcode.SetData = "Barcodebc123456789";

            barcode.SetColor = BCColor.Black;
            barcode.SetBackgroundColor = BCColor.White;

            barcode.AztecLayer = LayerMode.Default;

            barcode.AztecErrorCorrection = 50;

            barcode.SetBarcodeLocation = new BCPosition(100, 100);

            barcode.SetBarcodeSize = new BCSize(200, 200);

            barcode.GenerateBarcode(Graphics);

            File.Save("Aztec.pdf");
            Process.Start("Aztec.pdf");

        }
    }
}
